aboutsummaryrefslogtreecommitdiff
path: root/src/include
diff options
context:
space:
mode:
Diffstat (limited to 'src/include')
-rw-r--r--src/include/ndpi_api.h5
-rw-r--r--src/include/ndpi_private.h1
-rw-r--r--src/include/ndpi_typedefs.h12
3 files changed, 12 insertions, 6 deletions
diff --git a/src/include/ndpi_private.h b/src/include/ndpi_private.h
index afd2f48ac..e452df10a 100644
--- a/src/include/ndpi_private.h
+++ b/src/include/ndpi_private.h
@@ -296,6 +296,7 @@ struct ndpi_detection_module_config_struct {
int stun_opportunistic_tls_enabled;
int stun_max_packets_extra_dissection;
+ int rtp_max_packets_extra_dissection;
int stun_mapped_address_enabled;
int stun_response_origin_enabled;
int stun_other_address_enabled;
diff --git a/src/include/ndpi_typedefs.h b/src/include/ndpi_typedefs.h
index 8ca365d01..6b215aa70 100644
--- a/src/include/ndpi_typedefs.h
+++ b/src/include/ndpi_typedefs.h
@@ -1301,6 +1301,12 @@ struct ndpi_tls_obfuscated_heuristic_matching_set {
u_int32_t pkts[4];
};
+struct rtp_info {
+ u_int8_t payload_type;
+ u_int32_t evs_subtype;
+ bool payload_detected;
+};
+
struct ndpi_flow_struct {
u_int16_t detected_protocol_stack[NDPI_PROTOCOL_SIZE];
@@ -1601,10 +1607,8 @@ struct ndpi_flow_struct {
char *user_agent;
} ssdp;
- struct {
- u_int8_t payload_type;
- } rtp;
-} protos;
+ struct rtp_info rtp[2 /* directions */];
+ } protos;
/* **Packet** metadata for flows where monitoring is enabled. It is reset after each packet! */
struct ndpi_metadata_monitoring *monit;
diff --git a/src/include/ndpi_api.h b/src/include/ndpi_api.h
index 4a56da56f..467984f9f 100644
--- a/src/include/ndpi_api.h
+++ b/src/include/ndpi_api.h
@@ -602,10 +602,11 @@ extern "C" {
/**
* Return the name of a RTP payload type
*
* @par payload_type = the RTP payload type
* @return The symbolic payload type or "Unknown" if not found
*/
- const char* ndpi_rtp_payload_type2str(u_int8_t payload_type);
+ const char* ndpi_rtp_payload_type2str(u_int8_t payload_type, u_int32_t evs_payload_type);
/**
* Check if subprotocols of the specified master protocol are just
@@ -602,10 +602,11 @@ extern "C" {
* Return the name of a RTP payload type
*
- * @par payload_type = the RTP payload type
+ * @par payload_type = the RTP payload type
+ * @par evs_payload_type = EVS payload type (only in case payload_type is EVS)
* @return The symbolic payload type or "Unknown" if not found
*/